<?php

namespace Litecms\Salarymanagement\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Salarymanagement\Interfaces\SalarymanagementRepositoryInterface;

class SalarymanagementPublicController extends BaseController
{
    // use SalarymanagementWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Salarymanagement\Interfaces\SalarymanagementRepositoryInterface $salarymanagement
     *
     * @return type
     */
    public function __construct(SalarymanagementRepositoryInterface $salarymanagement)
    {
        $this->repository = $salarymanagement;
        parent::__construct();
    }

    /**
     * Show salarymanagement's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $salarymanagements = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$salarymanagement::$salarymanagement.names'))
            ->view('$salarymanagement::public.salarymanagement.index')
            ->data(compact('$salarymanagements'))
            ->output();
    }

    /**
     * Show salarymanagement's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $salarymanagements = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$salarymanagement::$salarymanagement.names'))
            ->view('$salarymanagement::public.salarymanagement.index')
            ->data(compact('$salarymanagements'))
            ->output();
    }

    /**
     * Show salarymanagement.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $salarymanagement = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$salarymanagement->name . trans('$salarymanagement::$salarymanagement.name'))
            ->view('$salarymanagement::public.salarymanagement.show')
            ->data(compact('$salarymanagement'))
            ->output();
    }

}
