<?php

namespace Litecms\Salarymanagement\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Salarymanagement\Http\Requests\SalarymanagementRequest;
use Litecms\Salarymanagement\Interfaces\SalarymanagementRepositoryInterface;
use Litecms\Salarymanagement\Models\Salarymanagement;

/**
 * Resource controller class for salarymanagement.
 */
class SalarymanagementResourceController extends BaseController
{

    /**
     * Initialize salarymanagement resource controller.
     *
     * @param type SalarymanagementRepositoryInterface $salarymanagement
     *
     * @return null
     */
    public function __construct(SalarymanagementRepositoryInterface $salarymanagement)
    {
        parent::__construct();
        $this->repository = $salarymanagement;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Salarymanagement\Repositories\Criteria\SalarymanagementResourceCriteria::class);
    }

    /**
     * Display a list of salarymanagement.
     *
     * @return Response
     */
    public function index(SalarymanagementRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Salarymanagement\Repositories\Presenter\SalarymanagementPresenter::class)
                ->$function();
        }

        $salarymanagements = $this->repository->paginate();

        return $this->response->title(trans('salarymanagement::salarymanagement.names'))
            ->view('salarymanagement::salarymanagement.index', true)
            ->data(compact('salarymanagements'))
            ->output();
    }

    /**
     * Display salarymanagement.
     *
     * @param Request $request
     * @param Model   $salarymanagement
     *
     * @return Response
     */
    public function show(SalarymanagementRequest $request, Salarymanagement $salarymanagement)
    {

        if ($salarymanagement->exists) {
            $view = 'salarymanagement::salarymanagement.show';
        } else {
            $view = 'salarymanagement::salarymanagement.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('salarymanagement::salarymanagement.name'))
            ->data(compact('salarymanagement'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new salarymanagement.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(SalarymanagementRequest $request)
    {

        $salarymanagement = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('salarymanagement::salarymanagement.name')) 
            ->view('salarymanagement::salarymanagement.create', true) 
            ->data(compact('salarymanagement'))
            ->output();
    }

    /**
     * Create new salarymanagement.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SalarymanagementRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $salarymanagement                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('salarymanagement::salarymanagement.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('salarymanagement/salarymanagement/' . $salarymanagement->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/salarymanagement/salarymanagement'))
                ->redirect();
        }

    }

    /**
     * Show salarymanagement for editing.
     *
     * @param Request $request
     * @param Model   $salarymanagement
     *
     * @return Response
     */
    public function edit(SalarymanagementRequest $request, Salarymanagement $salarymanagement)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('salarymanagement::salarymanagement.name'))
            ->view('salarymanagement::salarymanagement.edit', true)
            ->data(compact('salarymanagement'))
            ->output();
    }

    /**
     * Update the salarymanagement.
     *
     * @param Request $request
     * @param Model   $salarymanagement
     *
     * @return Response
     */
    public function update(SalarymanagementRequest $request, Salarymanagement $salarymanagement)
    {
        try {
            $attributes = $request->all();

            $salarymanagement->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('salarymanagement::salarymanagement.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('salarymanagement/salarymanagement/' . $salarymanagement->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('salarymanagement/salarymanagement/' . $salarymanagement->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the salarymanagement.
     *
     * @param Model   $salarymanagement
     *
     * @return Response
     */
    public function destroy(SalarymanagementRequest $request, Salarymanagement $salarymanagement)
    {
        try {

            $salarymanagement->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('salarymanagement::salarymanagement.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('salarymanagement/salarymanagement/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('salarymanagement/salarymanagement/' . $salarymanagement->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple salarymanagement.
     *
     * @param Model   $salarymanagement
     *
     * @return Response
     */
    public function delete(SalarymanagementRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('salarymanagement::salarymanagement.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('salarymanagement/salarymanagement'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/salarymanagement/salarymanagement'))
                ->redirect();
        }

    }

    /**
     * Restore deleted salarymanagements.
     *
     * @param Model   $salarymanagement
     *
     * @return Response
     */
    public function restore(SalarymanagementRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('salarymanagement::salarymanagement.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/salarymanagement/salarymanagement'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/salarymanagement/salarymanagement/'))
                ->redirect();
        }

    }

}
