<?php

namespace Litecms\Salarymanagement\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Salarymanagement\Models\Salarymanagement;

class SalarymanagementPolicy
{

    /**
     * Determine if the given user can view the salarymanagement.
     *
     * @param UserPolicy $user
     * @param Salarymanagement $salarymanagement
     *
     * @return bool
     */
    public function view(UserPolicy $user, Salarymanagement $salarymanagement)
    {
        if ($user->canDo('salarymanagement.salarymanagement.view') && $user->isAdmin()) {
            return true;
        }

        return $salarymanagement->user_id == user_id() && $salarymanagement->user_type == user_type();
    }

    /**
     * Determine if the given user can create a salarymanagement.
     *
     * @param UserPolicy $user
     * @param Salarymanagement $salarymanagement
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('salarymanagement.salarymanagement.create');
    }

    /**
     * Determine if the given user can update the given salarymanagement.
     *
     * @param UserPolicy $user
     * @param Salarymanagement $salarymanagement
     *
     * @return bool
     */
    public function update(UserPolicy $user, Salarymanagement $salarymanagement)
    {
        if ($user->canDo('salarymanagement.salarymanagement.edit') && $user->isAdmin()) {
            return true;
        }

        return $salarymanagement->user_id == user_id() && $salarymanagement->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given salarymanagement.
     *
     * @param UserPolicy $user
     * @param Salarymanagement $salarymanagement
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Salarymanagement $salarymanagement)
    {
        return $salarymanagement->user_id == user_id() && $salarymanagement->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given salarymanagement.
     *
     * @param UserPolicy $user
     * @param Salarymanagement $salarymanagement
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Salarymanagement $salarymanagement)
    {
        if ($user->canDo('salarymanagement.salarymanagement.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given salarymanagement.
     *
     * @param UserPolicy $user
     * @param Salarymanagement $salarymanagement
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Salarymanagement $salarymanagement)
    {
        if ($user->canDo('salarymanagement.salarymanagement.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
