<?php

namespace Litecms\Salarymanagement\Providers;

use Illuminate\Support\ServiceProvider;

class SalarymanagementServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'salarymanagement');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'salarymanagement');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.salarymanagement', function ($app) {
            return $this->app->make('Litecms\Salarymanagement\Salarymanagement');
        });

                // Bind Salarymanagement to repository
        $this->app->bind(
            'Litecms\Salarymanagement\Interfaces\SalarymanagementRepositoryInterface',
            \Litecms\Salarymanagement\Repositories\Eloquent\SalarymanagementRepository::class
        );

        $this->app->register(\Litecms\Salarymanagement\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Salarymanagement\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Salarymanagement\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.salarymanagement'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/salarymanagement.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/salarymanagement')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/salarymanagement')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
